@@ -23,6 +23,7 @@ import base64
 import os
 import posixpath
 import shutil
+import sys
 import tempfile
 import xml.etree.ElementTree as ET
 from functools import partial
@@ -314,6 +315,25 @@ class BaseRequestsMixIn:
         status, _, _ = self.request("GET", path2)
         assert status == 200
 
+    def test_move_between_colections(self):
+        """Move a item."""
+        status, _, _ = self.request("MKCALENDAR", "/calendar1.ics/")
+        assert status == 201
+        status, _, _ = self.request("MKCALENDAR", "/calendar2.ics/")
+        assert status == 201
+        event = get_file_content("event1.ics")
+        path1 = "/calendar1.ics/event1.ics"
+        path2 = "/calendar2.ics/event2.ics"
+        status, _, _ = self.request("PUT", path1, event)
+        assert status == 201
+        status, _, _ = self.request(
+            "MOVE", path1, HTTP_DESTINATION=path2, HTTP_HOST="")
+        assert status == 201
+        status, _, _ = self.request("GET", path1)
+        assert status == 404
+        status, _, _ = self.request("GET", path2)
+        assert status == 200
+
     def test_head(self):
         status, _, _ = self.request("HEAD", "/")
         assert status == 302
@@ -868,28 +888,45 @@ class BaseRequestsMixIn:
               <C:comp-filter name="VEVENT">
                 <C:time-range start="20170601T063000Z" end="20170601T070000Z"/>
               </C:comp-filter>
-            </C:comp-filter>"""], items=(6, 7, 8))
+            </C:comp-filter>"""], items=(6, 7, 8, 9))
         assert "href>/calendar.ics/event6.ics</" in answer
         assert "href>/calendar.ics/event7.ics</" in answer
         assert "href>/calendar.ics/event8.ics</" in answer
+        assert "href>/calendar.ics/event9.ics</" in answer
         answer = self._test_filter(["""
             <C:comp-filter name="VCALENDAR">
               <C:comp-filter name="VEVENT">
                 <C:time-range start="20170701T060000Z"/>
               </C:comp-filter>
-            </C:comp-filter>"""], items=(6, 7, 8))
+            </C:comp-filter>"""], items=(6, 7, 8, 9))
         assert "href>/calendar.ics/event6.ics</" in answer
         assert "href>/calendar.ics/event7.ics</" in answer
         assert "href>/calendar.ics/event8.ics</" in answer
+        assert "href>/calendar.ics/event9.ics</" not in answer
         answer = self._test_filter(["""
             <C:comp-filter name="VCALENDAR">
               <C:comp-filter name="VEVENT">
                 <C:time-range start="20170702T070000Z" end="20170704T060000Z"/>
               </C:comp-filter>
-            </C:comp-filter>"""], items=(6, 7, 8))
+            </C:comp-filter>"""], items=(6, 7, 8, 9))
         assert "href>/calendar.ics/event6.ics</" not in answer
         assert "href>/calendar.ics/event7.ics</" not in answer
         assert "href>/calendar.ics/event8.ics</" not in answer
+        assert "href>/calendar.ics/event9.ics</" not in answer
+        answer = self._test_filter(["""
+            <C:comp-filter name="VCALENDAR">
+              <C:comp-filter name="VEVENT">
+                <C:time-range start="20170602T075959Z" end="20170602T080000Z"/>
+              </C:comp-filter>
+            </C:comp-filter>"""], items=(9,))
+        assert "href>/calendar.ics/event9.ics</" in answer
+        answer = self._test_filter(["""
+            <C:comp-filter name="VCALENDAR">
+              <C:comp-filter name="VEVENT">
+                <C:time-range start="20170602T080000Z" end="20170603T083000Z"/>
+              </C:comp-filter>
+            </C:comp-filter>"""], items=(9,))
+        assert "href>/calendar.ics/event9.ics</" not in answer
 
     def test_time_range_filter_events_rrule(self):
         """Report request with time-range filter on events with rrules."""
@@ -992,17 +1029,19 @@ class BaseRequestsMixIn:
               <C:comp-filter name="VTODO">
                 <C:time-range start="20130801T000000Z" end="20131001T000000Z"/>
               </C:comp-filter>
-            </C:comp-filter>"""], "todo", items=(1, 2))
+            </C:comp-filter>"""], "todo", items=(1, 2, 9))
         assert "href>/calendar.ics/todo1.ics</" in answer
         assert "href>/calendar.ics/todo2.ics</" in answer
+        assert "href>/calendar.ics/todo9.ics</" in answer
         answer = self._test_filter(["""
             <C:comp-filter name="VCALENDAR">
               <C:comp-filter name="VTODO">
                 <C:time-range start="20140801T000000Z" end="20141001T000000Z"/>
               </C:comp-filter>
-            </C:comp-filter>"""], "todo", items=(1, 2))
+            </C:comp-filter>"""], "todo", items=(1, 2, 9))
         assert "href>/calendar.ics/todo1.ics</" not in answer
         assert "href>/calendar.ics/todo2.ics</" in answer
+        assert "href>/calendar.ics/todo9.ics</" in answer
         answer = self._test_filter(["""
             <C:comp-filter name="VCALENDAR">
               <C:comp-filter name="VTODO">
@@ -1019,6 +1058,13 @@ class BaseRequestsMixIn:
             </C:comp-filter>"""], "todo", items=(1, 2))
         assert "href>/calendar.ics/todo1.ics</" not in answer
         assert "href>/calendar.ics/todo2.ics</" not in answer
+        answer = self._test_filter(["""
+            <C:comp-filter name="VCALENDAR">
+              <C:comp-filter name="VTODO">
+                <C:time-range start="20130902T000000Z" end="20130906T235959Z"/>
+              </C:comp-filter>
+            </C:comp-filter>"""], "todo", items=(9,))
+        assert "href>/calendar.ics/todo9.ics</" not in answer
 
     def test_time_range_filter_journals(self):
         """Report request with time-range filter on journals."""
@@ -1128,7 +1174,7 @@ class BaseRequestsMixIn:
                  </prop>
                  %s
                </sync-collection>""" % sync_token_xml)
-        if sync_token and status == 412:
+        if sync_token and status == 409:
             return None, None
         assert status == 207
         xml = ET.fromstring(answer)
@@ -1405,6 +1451,16 @@ class BaseRequestsMixIn:
         assert status == 404
         assert headers.get("test") == "123"
 
+    @pytest.mark.skipif(sys.version_info < (3, 6),
+                        reason="Unsupported in Python < 3.6")
+    def test_timezone_seconds(self):
+        """Verify that timezones with minutes and seconds work."""
+        status, _, _ = self.request("MKCALENDAR", "/calendar.ics/")
+        assert status == 201
+        event = get_file_content("event_timezone_seconds.ics")
+        status, _, _ = self.request("PUT", "/calendar.ics/event.ics", event)
+        assert status == 201
+
     def test_missing_uid(self):
         """Verify that missing UIDs are added in a stable manner."""
         status, _, _ = self.request("MKCALENDAR", "/calendar.ics/")
